==> haskell-tls-session-manager-0.0.4-158-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls-session-manager
version:              0.0.4
visibility:           public
id:                   tls-session-manager-0.0.4-I7j8DTDest0EuaLuxbLjl0
key:                  tls-session-manager-0.0.4-I7j8DTDest0EuaLuxbLjl0
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance

category:             Web
abi:                  c7778ccf5040a0f99a97224bf190e9d5
exposed:              True
exposed-modules:      Network.TLS.SessionManager
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-8.10.4/site-local/tls-session-manager-0.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tls-session-manager-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/tls-session-manager-0.0.4

hs-libraries:         HStls-session-manager-0.0.4-I7j8DTDest0EuaLuxbLjl0
depends:
    auto-update-0.1.6-F49wuFItZe7AOsoVGTJ1vM base-4.14.1.0
    basement-0.0.12-5npdMLTFbggC6Tq5xCCXFT bytestring-0.10.12.0
    clock-0.8.2-9UFKXEvaIlvHBGUfGAYdEd
    memory-0.16.0-FcR25XxjAGsCy9iFRDcpya
    psqueues-0.2.7.2-BhOzMYHYS6r4OA0VkbJoCN
    tls-1.5.5-GPA2a5mc30RKrXE2ykflR9

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.4-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tls-session-manager
version:              0.0.4
visibility:           public
id:                   tls-session-manager-0.0.4-AP1umz1AuP78cFIblqW7HX
key:                  tls-session-manager-0.0.4-AP1umz1AuP78cFIblqW7HX
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance

category:             Web
abi:                  1f09ca33870fe8df247d7e979df192ba
exposed:              True
exposed-modules:      Network.TLS.SessionManager
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-8.10.4/site-local/tls-session-manager-0.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tls-session-manager-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/tls-session-manager-0.0.4

hs-libraries:         HStls-session-manager-0.0.4-AP1umz1AuP78cFIblqW7HX
depends:
    auto-update-0.1.6-3rfV0oeBaPp9X330oUm2q7 base-4.14.1.0
    basement-0.0.12-5npdMLTFbggC6Tq5xCCXFT bytestring-0.10.12.0
    clock-0.8.2-AKb2IHjn1jnBN8KCWciW9q
    memory-0.16.0-FcR25XxjAGsCy9iFRDcpya
    psqueues-0.2.7.2-7AORFFVGXKWCBDWyZVQPlf
    tls-1.5.5-8HQwqhH6pip2DmmSlnOAM5

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
